@@ -2,6 +2,7 @@
 
 set -euo pipefail
 
+export PYTHON=python
 export APP_NAME="TortoiseHg"
 export QT_VERSION="qt5"
 
@@ -47,5 +48,10 @@ if [ -d dist/${APP_NAME}.app ]; then
     src/thg/contrib/sign-py2app.sh dist/${APP_NAME}.app
   fi
 
+  # The Mercurial builds append -python2 for py2, but do nothing special for
+  # py3.  Do the same for consistency.
+  PY_FILE_NAME="-python2"
+  export PY_FILE_NAME
+
   toolchain/receipts/createDmg.sh
 fi
