@@ -4,7 +4,7 @@
 # Copyright 2008 TK Soh <teekaysoh@gmail.com>
 #
 # This software may be used and distributed according to the terms of the
-# GNU General Public License version 2, incorporated herein by reference.
+# GNU General Public License version 2 or any later version.
 
 from __future__ import absolute_import, print_function
 
@@ -57,7 +57,7 @@ except ImportError:
     config_nofork = None
 
 shortlicense = b'''
-Copyright (C) 2008-2021 Steve Borho <steve@borho.org> and others.
+Copyright (C) 2008-2022 Steve Borho <steve@borho.org> and others.
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 '''
@@ -144,9 +144,13 @@ def dispatch(args, u=None):
     except Exception as e:
         if b'--debugger' in args:
             pdb.post_mortem(sys.exc_info()[2])
-        if u.configbool(b'tortoisehg', b'traceback'):
+        if u and u.configbool(b'tortoisehg', b'traceback'):
             raise
         qtapp.earlyBugReport(e)
+
+        if not u:
+            raise
+
         return -1
     except KeyboardInterrupt:
         print(_('\nCaught keyboard interrupt, aborting.\n'))
@@ -226,8 +230,8 @@ def get_lines_from_listfile(filename, isutf8):
         if filename == b'-':
             lines = [x.replace(b"\n", b"") for x in procutil.stdin.readlines()]
         else:
-            fd = open(filename, "r")
-            lines = [ x.replace("\n", "") for x in fd.readlines() ]
+            fd = open(filename, "rb")
+            lines = [ x.replace(b"\n", b"") for x in fd.readlines() ]
             fd.close()
             os.unlink(filename)
         if isutf8:
@@ -314,7 +318,7 @@ def _parse(ui, args):
     try:
         args = fancyopts.fancyopts(args, c, cmdoptions, True)
     except getopt.GetoptError as inst:
-        raise error.CommandError(cmd, inst)
+        raise error.CommandError(cmd, stringutil.forcebytestr(inst))
 
     # separate global options back out
     for o in globalopts:
@@ -880,8 +884,9 @@ def help_(ui, name=None, with_version=False, **opts):
                 continue
             #doc = gettext(doc)
             if not doc:
-                doc = _("(no help text available)")
-            h[f] = hglib.fromunicode(doc.splitlines()[0].rstrip())
+                h[f] = _("(no help text available)")
+            else:
+                h[f] = hglib.fromunicode(doc.splitlines()[0].rstrip())
             cmds[f] = c
 
         if not h:
